@@ -1,41 +1,7 @@
 # -*- coding: utf-8 -*-
 
-"""unittest-xml-reporting is a PyUnit-based TestRunner that can export test
-results to XML files that can be consumed by a wide range of tools, such as
-build systems, IDEs and Continuous Integration servers.
-
-This module provides the XMLTestRunner class, which is heavily based on the
-default TextTestRunner. This makes the XMLTestRunner very simple to use.
-
-The script below, adapted from the unittest documentation, shows how to use
-XMLTestRunner in a very simple way. In fact, the only difference between this
-script and the original one is the last line:
-
-import random
-import unittest
-import xmlrunner
-
-class TestSequenceFunctions(unittest.TestCase):
-    def setUp(self):
-        self.seq = range(10)
-
-    def test_shuffle(self):
-        # make sure the shuffled sequence does not lose any elements
-        random.shuffle(self.seq)
-        self.seq.sort()
-        self.assertEqual(self.seq, range(10))
-
-    def test_choice(self):
-        element = random.choice(self.seq)
-        self.assert_(element in self.seq)
-
-    def test_sample(self):
-        self.assertRaises(ValueError, random.sample, self.seq, 20)
-        for element in random.sample(self.seq, 5):
-            self.assert_(element in self.seq)
-
-if __name__ == '__main__':
-    unittest.main(testRunner=xmlrunner.XMLTestRunner(output='test-reports'))
+"""This module provides the XMLTestRunner class, which is heavily based on the
+default TextTestRunner.
 """
 
 import os
@@ -202,13 +168,20 @@ class _XMLTestResult(_TextTestResult):
     
     _report_testsuite = staticmethod(_report_testsuite)
     
+    def _test_method_name(test_method):
+        "Returns the test method name."
+        test_id = test_method.id()
+        return test_id.split('.')[-1]
+    
+    _test_method_name = staticmethod(_test_method_name)
+    
     def _report_testcase(suite_name, test_result, xml_testsuite, xml_document):
         "Appends a testcase section to the XML document."
         testcase = xml_document.createElement('testcase')
         xml_testsuite.appendChild(testcase)
         
         testcase.setAttribute('classname', suite_name)
-        testcase.setAttribute('name', test_result.test_method._testMethodName)
+        testcase.setAttribute('name', _XMLTestResult._test_method_name(test_result.test_method))
         testcase.setAttribute('time', '%.3f' % test_result.get_elapsed_time())
         
         if (test_result.outcome != _TestInfo.SUCCESS):
@@ -217,9 +190,9 @@ class _XMLTestResult(_TextTestResult):
             testcase.appendChild(failure)
             
             failure.setAttribute('type', test_result.err[0].__name__)
-            failure.setAttribute('message', test_result.err[1].message)
+            failure.setAttribute('message', unicode(test_result.err[1]))
             
-            error_info = test_result.get_error_info()
+            error_info = unicode(test_result.get_error_info(), "utf-8")
             failureText = xml_document.createCDATASection(error_info)
             failure.appendChild(failureText)
     
@@ -260,7 +233,7 @@ class _XMLTestResult(_TextTestResult):
             for test in tests:
                 _XMLTestResult._report_testcase(suite, test, testsuite, doc)
             _XMLTestResult._report_output(test_runner, testsuite, doc)
-            xml_content = doc.toprettyxml(indent='\t')
+            xml_content = doc.toprettyxml(indent='\t', encoding="utf-8")
             
             if type(test_runner.output) is str:
                 report_file = file('%s%sTEST-%s.xml' % \
@@ -350,6 +323,7 @@ class XMLTestRunner(TextTestRunner):
             self.stream.writeln('Generating XML reports...')
             result.generate_reports(self)
         finally:
+            pass
             self._restore_standard_output()
         
         return result
